export interface BotConfig {
	// Common Fields
	name: string;
	version: string;
	token: string;
	localToken: string;
	prefix: string;
	owner: bigint;
	logChannel: bigint;
	reportChannel: bigint;
	devServer: bigint;

	// Most bots use these
	db?: DBConfig;
	links?: LinksConfig;

	// Rarely used in bots
	emojis?: EmojiConfig[];

	// Public Bots Only
	botLists?: BotListsConfig[];

	// Artificer Specific, included for compatibility
	postfix?: string;
	limits?: ArtificerLimits;
	api?: ArtificerApi;
	logRolls?: boolean;
}

// DB Config, every bot uses MySQL for compatibility with each other
export interface DBConfig {
	host: string;
	localhost: string;
	port: number;
	username: string;
	password: string;
	name: string;
}

// Links Config, holds list of named strings that are used in many places
export interface LinksConfig {
	sourceCode: string;
	supportServer: string;
	addToCalendar: string;
	creatorIcon: string;
}

// Emoji to dynamically add more emoji to a bot
export interface EmojiConfig {
	name: string;
	aliases: string[];
	id: string;
	animated: boolean;
	deleteSender: boolean;
}

// Bot List Config for automatically posting statistics
export interface BotListsConfig {
	name: string;
	enabled: boolean;
	apiUrl: string;
	headers: BotListsEntity[];
	body: BotListBody;
}
export interface BotListsEntity {
	header: string;
	value: string;
}
export interface BotListBody {
	server_count?: string;
	guildCount?: string;
	guilds?: string;
}

// Types just for Artificer
export interface ArtificerLimits {
	maxLoops: number;
	maxWorkers: number;
	workerTimeout: number;
}
export interface ArtificerApi {
	enable: boolean;
	publicDomain: string;
	port: number;
	supportURL: string;
	rateLimitTime: number;
	rateLimitCnt: number;
	admin: bigint;
	adminKey: string;
	email: bigint;
}
